==> opencadc-tap-1.0.0.tgz: package/tap.js <==
'use strict'

var Registry = require('opencadc-registry')
var rp = require('request-promise')
var URL = require('url')

module.exports = TAP

/**
 * TAP Client to query a TAP services located by the serviceID.
 *
 * @param {{}} opts    Optional configuration options.
 * @param {String} configuration.resourceID  Resource ID URI for the desired TAP service.
 * @param {String} configuration.standardID  Standard ID URI to lookup.
 * @constructor
 */
function TAP(opts) {
  var defaultConfig = {
    resourceID: 'ivo://cadc.nrc.ca/tap',
    standardID: 'ivo://ivoa.net/std/TAP#sync-1.1'
  }

  this.options = opts || {}

  this.resourceURI = URL.parse(
    this.options.resourceID || defaultConfig.resourceID
  )
  this.standardURI = URL.parse(
    this.options.standardID || defaultConfig.standardID
  )

  /**
   * Execute a query and return a Promise.
   *
   * @param {{}} input    Object with query inputs.
   * @param {String} input.language='ADQL'    TAP query language.  Defaults to ADQL.
   * @param {String} input.queryString   TAP query to execute
   * @param {String} input.format='CSV'   Format of results.  Defaults to CSV.
   * @param {{}} callback   Optional callback function.  Defaults to returned promise.
   * @returns {Promise}
   */
  this.query = async function(input, callback) {
    var endPoint = this.options.endPoint
    var p
    var payload = {
      LANG: input.language || 'ADQL',
      QUERY: input.queryString,
      REQUEST: 'doQuery',
      FORMAT: input.format || 'CSV',
      phase: 'run'
    }

    var requestOptions = {
      method: 'POST',
      form: payload,
      followAllRedirects: true
    }

    if (endPoint) {
      requestOptions.uri = endPoint
      p = rp(requestOptions)
    } else {
      var registry = new Registry()
      p = registry
        .serviceURL(this.resourceURI.href, this.standardURI.href)
        .then(function(serviceURLEndpoint) {
          requestOptions.uri = serviceURLEndpoint
          return rp(requestOptions)
        })
    }

    if (callback) {
      p.then(callback)
    } else {
      return p
    }
  }
}

==> opencadc-tap-1.0.8.tgz: package/tap.js <==
'use strict'

var Registry = require('opencadc-registry')
var axios = require('axios')
var URL = require('url')

module.exports = TAP

/**
 * TAP Client to query a TAP services located by the serviceID.
 *
 * @param {{}} opts    Optional configuration options.
 * @param {String} configuration.resourceID  Resource ID URI for the desired TAP service.
 * @param {String} configuration.standardID  Standard ID URI to lookup.
 * @constructor
 */
function TAP(opts) {
  var defaultConfig = {
    resourceID: 'ivo://cadc.nrc.ca/tap',
    standardID: 'ivo://ivoa.net/std/TAP#sync-1.1'
  }

  this.options = opts || {}

  this.resourceURI = URL.parse(
    this.options.resourceID || defaultConfig.resourceID
  )
  this.standardURI = URL.parse(
    this.options.standardID || defaultConfig.standardID
  )

  /**
   * Execute a query and return a Promise.
   *
   * @param {{}} input    Object with query inputs.
   * @param {String} input.language='ADQL'    TAP query language.  Defaults to ADQL.
   * @param {String} input.queryString   TAP query to execute
   * @param {String} input.format='CSV'   Format of results.  Defaults to CSV.
   * @param {boolean} input.secureFlag=false  Whether to look for HTTPS Service URLs.
   * @param {{}} callback   Optional callback function.  Defaults to returned promise.
   * @returns {Promise}
   */
  this.query = async function(input, callback) {
    var endPoint = this.options.endPoint
    var secureFlag = this.options.secureFlag || false
    var p
    var payload = {
      LANG: input.language || 'ADQL',
      QUERY: input.queryString,
      REQUEST: 'doQuery',
      FORMAT: input.format || 'CSV'
    }

    var axiosConfig = {
      method: 'post',
      data: payload,
      transformRequest: [
        function(data, headers) {
          let serializedData = []

          for (const k in data) {
            if (data[k]) {
              serializedData.push(`${k}=${encodeURIComponent(data[k])}`)
            }
          }

          return serializedData.join('&')
        }
      ],
      withCredentials: true,
      crossDomain: true
    }

    if (endPoint) {
      console.log(`Using configured endPoint at ${endPoint}`)
      axiosConfig.url = endPoint
      p = axios(axiosConfig)
    } else {
      var registry = new Registry()
      p = registry
        .serviceURL(this.resourceURI.href, this.standardURI.href, secureFlag)
        .then(function(serviceURLEndpoint) {
          axiosConfig.url = serviceURLEndpoint
          return axios(axiosConfig)
        })
    }

    if (callback) {
      p.then(callback)
    } else {
      return p
    }
  }
}
